@@ -19,9 +19,10 @@ from tiddlywebplugins.instancer.util import get_tiddler_locations
 from tiddlywebplugins.tiddlyspace.instance import store_contents
 
 from tiddlywebplugins.tiddlyspace.config import config as space_config
+from tiddlywebplugins.tiddlyspace.controlview import (ControlView,
+        DropPrivs, AllowOrigin)
 from tiddlywebplugins.tiddlyspace.handler import (home, safe_mode,
-        friendly_uri, get_identities,
-        ControlView, DropPrivs, AllowOrigin)
+        friendly_uri, get_identities)
 from tiddlywebplugins.tiddlyspace.spaces import (
         add_spaces_routes, change_space_member)
 from tiddlywebplugins.prettyerror import PrettyHTTPExceptor
@@ -29,7 +30,7 @@ from tiddlywebplugins.prettyerror import PrettyHTTPExceptor
 import tiddlywebplugins.status
 
 
-__version__ = '0.9.41'
+__version__ = '0.9.42'
 
 
 def init(config):
@@ -38,7 +39,7 @@ def init(config):
     """
     import tiddlywebwiki
     import tiddlywebplugins.logout
-    import tiddlywebplugins.virtualhosting # calling init not required
+    import tiddlywebplugins.virtualhosting  # calling init not required
     import tiddlywebplugins.magicuser
     import tiddlywebplugins.socialusers
     import tiddlywebplugins.mselect
@@ -51,6 +52,7 @@ def init(config):
     import tiddlywebplugins.form
     import tiddlywebplugins.reflector
     import tiddlywebplugins.lazy
+    import tiddlywebplugins.privateer
 
     @make_command()
     def addmember(args):
@@ -84,7 +86,7 @@ def init(config):
                 store.delete(tiddler)
             except NoTiddlerError:
                 std_error_message(
-                        'error deleting deleting tiddler %s from bag %s: %s' % (
+                        'error deleting tiddler %s from bag %s: %s' % (
                             title, bag, 'no such tiddler'))
             return True
         else:
@@ -106,18 +108,19 @@ def init(config):
     tiddlywebplugins.form.init(config)
     tiddlywebplugins.reflector.init(config)
     tiddlywebplugins.lazy.init(config)
+    tiddlywebplugins.privateer.init(config)
 
     # XXX This is required to work around issues with twp.instancer.
     # Without this, instance information from tiddlywebwiki wins
     # because each plugin does its own get_tiddler_locations.
     # This only fixes 'twanager update', instance creation
     # still does not have the right information, thus requiring a
-    # twanager update after instance creation. Presumably the 
+    # twanager update after instance creation. Presumably the
     # instance script needs to do something similar.
     config['instance_tiddlers'] = get_tiddler_locations(store_contents,
             'tiddlywebplugins.tiddlyspace')
 
-    if 'selector' in config: # system plugin
+    if 'selector' in config:  # system plugin
         replace_handler(config['selector'], '/', dict(GET=home))
         config['selector'].add('/_safe', GET=safe_mode, POST=safe_mode)
         add_spaces_routes(config['selector'])
